==> xl-security-23.1.5-sources.jar: com/xebialabs/deployit/security/authentication/BasicAuthWithRememberMeFilter.java <==
package com.xebialabs.deployit.security.authentication;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.crypto.codec.Base64;
import org.springframework.security.web.AuthenticationEntryPoint;
import org.springframework.security.web.authentication.www.BasicAuthenticationFilter;

public class BasicAuthWithRememberMeFilter extends BasicAuthenticationFilter {

    public BasicAuthWithRememberMeFilter(AuthenticationManager authenticationManager, AuthenticationEntryPoint authenticationEntryPoint) {
        super(authenticationManager, authenticationEntryPoint);
    }

    @Override
    protected void onSuccessfulAuthentication(HttpServletRequest request, HttpServletResponse response, Authentication authResult) throws IOException {
        // Extract password because that is no longer in authResult.
        String header = request.getHeader("Authorization");
        String[] tokens = extractAndDecodeHeader(header, request);
        UsernamePasswordAuthenticationToken token = new UsernamePasswordAuthenticationToken(tokens[0], tokens[1], authResult.getAuthorities());
        token.setDetails(authResult.getDetails());
        if (request.getRequestURI().endsWith("logout")  && request.getParameterMap().isEmpty()) {
            logger.info("Logging out " + token.getName());
            RememberMe.forget(token);
        } else {
            RememberMe.remember(token);
        }
    }

    /**
     * Decodes the header into a username and password.
     *
     * @throws BadCredentialsException if the Basic header is not present or is not valid Base64
     */
    private String[] extractAndDecodeHeader(String header, HttpServletRequest request) throws IOException {

        byte[] base64Token = header.substring(6).getBytes("UTF-8");
        byte[] decoded;
        try {
            decoded = Base64.decode(base64Token);
        } catch (IllegalArgumentException e) {
            throw new BadCredentialsException("Failed to decode basic authentication token");
        }

        String token = new String(decoded, getCredentialsCharset(request));

        int delim = token.indexOf(":");

        if (delim == -1) {
            throw new BadCredentialsException("Invalid basic authentication token");
        }
        return new String[] {token.substring(0, delim), token.substring(delim + 1)};
    }
}

==> xl-security-24.3.5-sources.jar: com/xebialabs/deployit/security/authentication/BasicAuthWithRememberMeFilter.java <==
package com.xebialabs.deployit.security.authentication;

import java.io.IOException;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.crypto.codec.Base64;
import org.springframework.security.web.AuthenticationEntryPoint;
import org.springframework.security.web.authentication.www.BasicAuthenticationFilter;

public class BasicAuthWithRememberMeFilter extends BasicAuthenticationFilter {

    public BasicAuthWithRememberMeFilter(AuthenticationManager authenticationManager, AuthenticationEntryPoint authenticationEntryPoint) {
        super(authenticationManager, authenticationEntryPoint);
    }

    @Override
    protected void onSuccessfulAuthentication(HttpServletRequest request, HttpServletResponse response, Authentication authResult) throws IOException {
        // Extract password because that is no longer in authResult.
        String header = request.getHeader("Authorization");
        String[] tokens = extractAndDecodeHeader(header, request);
        UsernamePasswordAuthenticationToken token = new UsernamePasswordAuthenticationToken(tokens[0], tokens[1], authResult.getAuthorities());
        token.setDetails(authResult.getDetails());
        if (request.getRequestURI().endsWith("logout")  && request.getParameterMap().isEmpty()) {
            logger.info("Logging out " + token.getName());
            RememberMe.forget(token);
        } else {
            RememberMe.remember(token);
        }
    }

    /**
     * Decodes the header into a username and password.
     *
     * @throws BadCredentialsException if the Basic header is not present or is not valid Base64
     */
    private String[] extractAndDecodeHeader(String header, HttpServletRequest request) throws IOException {

        byte[] base64Token = header.substring(6).getBytes("UTF-8");
        byte[] decoded;
        try {
            decoded = Base64.decode(base64Token);
        } catch (IllegalArgumentException e) {
            throw new BadCredentialsException("Failed to decode basic authentication token");
        }

        String token = new String(decoded, getCredentialsCharset(request));

        int delim = token.indexOf(":");

        if (delim == -1) {
            throw new BadCredentialsException("Invalid basic authentication token");
        }
        return new String[] {token.substring(0, delim), token.substring(delim + 1)};
    }
}
